/***************************************
 * Offset off parameters inside the    *
 * descriptor of the LECROY 9300       *
 * serie digital oscilloscope.         *
 * (c) Jean-Marie Bussat from the      *
 * "Remote control manual"             *
 ***************************************/
 
#define DESCRIPTOR_NAME		0
#define TEMPLATE_NAME		16
#define COMM_TYPE		32
#define COMM_ORDER		34
#define WAVE_DESCRIPTOR		36
#define USER_TEXT		40
#define RES_DESC1		44
#define TRIGTIME_ARRAY		48
#define RIS_TIME_ARRAY		52
#define RES_ARRAY_1		56
#define WAVE_ARRAY_1		60
#define WAVE_ARRAY_2		64
#define RES_ARRAY2		68
#define RES_ARRAY3		72
#define INSTRUMENT_NAME		76
#define INSTRUMENT_NUMBER	92
#define TRACE_LABEL		96
#define RESERVED1		112
#define RESERVED2		114
#define WAVE_ARRAY_COUNT	116
#define PNTS_PER_SCREEN		120
#define FIRST_VALID_PNT		124
#define LAST_VALID_PNT		128
#define FIRST_POINT		132
#define SPARSING_FACTOR		136
#define SEGMENT_INDEX		140
#define SUBARRAY_COUNT		144
#define SWEEPS_PER_ACQ		148
#define OBSOLETE1		152
#define VERTICAL_GAIN		156
#define VERTICAL_OFFSET		160
#define MAX_VALUE		164
#define MIN_VALUE		168
#define NOMINAL_BITS		172
#define NOM_SUBARRAY_COUNT	174
#define HORIZ_INTERVAL		176
#define HORIZ_OFFSET		180
#define PIXEL_OFFSET		188
#define VERTUNIT		196
#define HORUNIT			244
#define RESERVED3		292
#define RESERVED4		294
#define TRIGGER_TIME		296
#define ACQ_DURATION		312
#define RECORD_TYPE		316
#define PROCESSING_DONE		318
#define RESERVED5		320
#define RIS_SWEEP		322
#define TIMEBASE		324
#define VERT_COUPLING		326
#define PROBE_ATT		328
#define FIXED_VERT_GAIN		332
#define BANDWIDTH_LIMIT		334
#define VERTICAL_VERNIER	336
#define ACQ_VERT_OFFSET		340
#define WAVE_SOURCE		344

/************************************
 * timestamp structure definition   *
 ************************************/
typedef struct {
	double	seconds;
	char	minutes;
	char	hours;
	char	days;
	char	months;
	short	year;
	short	unused;
	} time_stamp;

/************************************
 * Descriptor structure definition  *
 ************************************/
typedef struct {
	char	descriptor_name[16];
	char	template_name[16];
	short	comm_type;
	short	comm_order;
	long	wave_descriptor;
	long	user_text;
	long	res_desc1;
	long	trigtime_array;
	long	ris_time_array;
	long	res_array1;
	long	wave_array_1;
	long	wave_array_2;
	long	res_array2;
	long	res_array3;
	char	instrument_name[16];
	long	instrument_number;
	char	trace_label[16];
	short	reserved1;
	short	reserved2;
	long	wave_array_count;
	long	pnts_per_screen;
	long	first_valid_pnt;
	long	last_valid_pnt;
	long	fisrt_point;
	long	sparsing_factor;
	long	segment_index;
	long	subarray_count;
	long	sweeps_per_acq;
	long	obsolete1;
	float	vertical_gain;
	float	vertical_offset;
	float	max_value;
	float	min_value;
	short	nominal_bits;
	short	nom_subarray_count;
	float	horiz_interval;
	double	horiz_offset;
	double	pixel_offset;
	char	vertunit[48];
	char	horunit[48];
	short	reserved3;
	short	reserved4;
	time_stamp	trigger_time;
	float	acq_duration;
	short	record_type;
	short	processing_done;
	short	reserved5;
	short	ris_sweeps;
	short	timebase;
	short	vert_coupling;
	float	probe_att;
	short	fixed_vert_gain;
	short	bandwidth_limit;
	float	vertical_vernier;
	float	acq_vert_offset;
	short	wave_source;
	} descriptor;

/***************************************
 * Some constants for the descriptor   *
 ***************************************/
char *record_type[]={"Single_sweep",
			"Interleaved",
			"Histogram",
			"Trend",
			"Filter_coefficient",
			"Complex",
			"Extrema",
			"Sequence_obsolete"};
			
char *processing_done[]={"No_processing",
				"FIR_filter",
				"Interpolated",
				"Sparsed",
				"Autoscaled",
				"No_result",
				"Rolling",
				"Cumulative"};
				
char *timebase[]={"1ps/div",
			"2ps/div",
			"5ps/div",
			"10ps/div",
			"20ps/div",
			"50ps/div",
			"100ps/div",
			"200ps/div",
			"500ps/div",
			"1ns/div",
			"2ns/div",
			"5ns/div",
			"10ns/div",
			"20ns/div",
			"50ns/div",
			"100ns/div",
			"200ns/div",
			"500ns/div",
			"1us/div",
			"2us/div",
			"5us/div",
			"10us/div",
			"20us/div",
			"50us/div",
			"100us/div",
			"200us/div",
			"500us/div",
			"1ms/div",
			"2ms/div",
			"5ms/div",
			"10ms/div",
			"20ms/div",
			"50ms/div",
			"100ms/div",
			"200ms/div",
			"500ms/div",
			"1s/div",
			"2s/div",
			"5s/div",
			"10s/div",
			"20s/div",
			"50s/div",
			"100s/div",
			"200s/div",
			"500s/div",
			"1ks/div",
			"2ks/div",
			"5ks/div",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			" ",
			"External"};

float time_div[]={	1.0e-12,
			2.0e-12,
			5.0e-12,
			10.0e-12,
			20.0e-12,
			50.0e-12,
			100.0e-12,
			200.0e-12,
			500.0e-12,
			1.0e-9,
			2.0e-9,
			5.0e-9,
			10.0e-9,
			20.0e-9,
			50.0e-9,
			100.0e-9,
			200.0e-9,
			500.0e-9,
			1.0e-6,
			2.0e-6,
			5.0e-6,
			10.0e-6,
			20.0e-6,
			50.0e-6,
			100.0e-6,
			200.0e-6,
			500.0e-6,
			1.0e-3,
			2.0e-3,
			5.0e-3,
			10.0e-3,
			20.0e-3,
			50.0e-3,
			100.0e-3,
			200.0e-3,
			500.0e-3,
			1.0,
			2.0,
			5.0,
			10.0,
			20.0,
			50.0,
			100.0,
			200.0,
			500.0,
			1000.0,
			2000.0,
			5000.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			0.0,
			-1.0};
			
char *fixed_vert_gain[]={"1uV/div",
			"2uV/div",
			"5uV/div",
			"10uV/div",
			"20uV/div",
			"50uV/div",
			"100uV/div",
			"200uV/div",
			"500uV/div",
			"1mV/div",
			"2mV/div",
			"5mV/div",
			"10mV/div",
			"20mV/div",
			"50mV/div",
			"100mV/div",
			"200mV/div",
			"500mV/div",
			"1V/div",
			"2V/div",
			"5V/div",
			"10V/div",
			"20V/div",
			"50V/div",
			"100V/div",
			"200V/div",
			"500V/div",
			"1kV/div"};
			
char *vert_coupling[]={"DC_50_Ohms",
			"Ground",
			"DC_1MOhms",
			"Ground",
			"AC_1MOhms"};
			
char *wave_source[]={"Channel_1",
			"Channel_2",
			"Channel_3",
			"Channel_4",
			" ",
			" ",
			" ",
			" ",
			" ",
			"Unknown"};

/*****************************************
 * Basic functions for GPIB transactions *
 *****************************************/

int gpib_find(device)
char *device;
{
	int dev;

	if((dev=ibfind(device)) & ERR)
	{
		fprintf(stderr,"ERROR - Can't find %s\n",device);
		exit(1);
	}
	else
		return(dev);
}

void gpib_write(dev,str)
int dev;
char *str;
{
	if( ibwrt(dev,str,strlen(str)) & ERR)
	{
		fprintf(stderr,"GPIB Write error\n");
		exit(1);
	}
}

void gpib_read(dev,buffer,size)
int dev;
char *buffer;
long size;
{
	if( ibrd(dev,buffer,size) & ERR)
	{
		fprintf(stderr,"GPIB Read error\n");
		exit(1);
	}
}

void gpib_online(dev)
int dev;
{
	if( ibonl(dev,1) & ERR)
	{
		fprintf(stderr,"Can't set the board online\n");
		exit(1);
	}
}

void gpib_SIC(dev)
int dev;
{
	if( ibsic(dev) & ERR)
	{
		fprintf(stderr,"Can't send SIC\n");
		exit(1);
	}
}

void gpib_REN(dev)
int dev;
{
	if( ibsre(dev,1) & ERR)
	{
		fprintf(stderr,"Can't send REN\n");
		exit(1);
	}
}






































































































